@@ -20,7 +20,7 @@
  *
  * Author: Josh MacDonald <jmacd@CS.Berkeley.EDU>
  *
- * $Id: xdelta.c 1.4.1.50.1.2 Fri, 29 Jun 2001 06:01:08 -0700 jmacd $
+ * $Id: xdelta.c 1.4.1.50.1.4 Sun, 28 Jan 2007 12:21:11 -0800 jmacd $
  */
 
 #define G_DISABLE_ASSERT
@@ -37,7 +37,7 @@ const guint xdelta_major_version = 1;
 /* $Format: "const guint xdelta_minor_version = $ReleaseMinorVersion$;" $ */
 const guint xdelta_minor_version = 1;
 /* $Format: "const guint xdelta_micro_version = $ReleaseMicroVersion$;" $ */
-const guint xdelta_micro_version = 3;
+const guint xdelta_micro_version = 4;
 
 /* Control functions.
  */
@@ -250,6 +250,19 @@ __xdp_generator_new (const char* version)
   return xg;
 }
 
+void
+xdp_generator_free (XdeltaGenerator *gen)
+{
+  int i;
+
+  for (i = 0; i < gen->sources->len; i += 1)
+    xdp_source_free (gen->sources->pdata[i]);
+
+  g_ptr_array_free (gen->sources, TRUE);
+  g_free ((void*) gen->table);
+  g_free (gen);
+}
+
 void
 init_pos (XdeltaStream* str, XdeltaPos* pos)
 {
@@ -303,6 +316,8 @@ xdp_source_index_read (XdeltaSource    *xs,
   if (! ss)
     return FALSE;
 
+  /* TODO: free ss */
+
   if (! unserialize_xdeltaindex (ss, &index))
     return FALSE;
 
@@ -312,8 +327,6 @@ xdp_source_index_read (XdeltaSource    *xs,
   xs->ck_count = index->index_len;
   xs->cksums = index->index;
 
-  /* @@@ how to free this? */
-
   return TRUE;
 }
 
@@ -1406,6 +1419,8 @@ xdp_control_read (XdeltaStream    *cont_in)
   if (! src)
     return NULL;
 
+  /* TODO: free src */
+
   if (! serializeio_unserialize_generic_acceptable (src, ST_XdeltaControl | ST_Version0Control, & type, (void**) & cont))
     return NULL;
 
